@@ -19,8 +19,10 @@ def json_input():
     except json.decoder.JSONDecodeError:
         return res
 
-def camel_to_snake(text:str) -> str:
-    return ''.join(['_'+i.lower() if i.isupper() else i for i in text]).lstrip('_')
+
+def camel_to_snake(text: str) -> str:
+    return "".join(["_" + i.lower() if i.isupper() else i for i in text]).lstrip("_")
+
 
 def apply_func_to_keys(dictionary: dict, func) -> dict:
     new = {}
@@ -29,4 +31,4 @@ def apply_func_to_keys(dictionary: dict, func) -> dict:
             new[func(key)] = apply_func_to_keys(dictionary[key], func)
         else:
             new[func(key)] = dictionary[key]
-    return new
\ No newline at end of file
+    return new
